"use strict";

require("core-js/modules/es.array.every");

require("core-js/modules/es.array.filter");

require("core-js/modules/es.array.includes");

require("core-js/modules/es.array.index-of");

require("core-js/modules/es.array.map");

require("core-js/modules/es.array.some");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isBooleanSwitch = exports.allBooleanValues = exports.default = void 0;

var _react = require("react");

var _callOnChange = _interopRequireDefault(require("../../utils/callOnChange"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var allBooleanValues = function allBooleanValues(options) {
  return options.every(function (option) {
    return ["false", "true"].includes(option.value);
  });
};

exports.allBooleanValues = allBooleanValues;

var isBooleanSwitch = function isBooleanSwitch(props) {
  return (props.options.length === 1 || props.options.length === 2 && !props.multiple) && allBooleanValues(props.options);
};

exports.isBooleanSwitch = isBooleanSwitch;

var useUpdateSelection = function useUpdateSelection(props) {
  var isCheckRadio = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  var originalSelection = props.selection;
  var selection = props.selection; // Make sure selection reacts to prop changes

  (0, _react.useEffect)(function () {
    var booleanSwitch = isCheckRadio ? isBooleanSwitch(props) : false;

    if (!props.allowDuplicates) {
      // No duplicates, distinct
      var selectionValues = selection.map(function (item) {
        return item.value;
      });
      var newSelection = selection.filter(function (item, index) {
        return selectionValues.indexOf(item.value) === index;
      }); // eslint-disable-next-line

      if (newSelection.length !== selection.length) selection = newSelection;
    }

    if (!props.multiple && selection.length > 1) {
      // Single, only allow one selection
      selection = [selection[0]];
    }

    if (!props.creatable && !booleanSwitch) {
      // Not creatable, only allow selections in the options
      var _newSelection = selection.filter(function (item) {
        return props.options.some(function (option) {
          return option.value === item.value;
        });
      });

      if (_newSelection.length !== selection.length) selection = _newSelection;
    }

    if (!selection.length && booleanSwitch) {
      // When changing to true/false switch, it should never be empty
      selection = [{
        value: "false"
      }];

      if (props.options.length === 1 && props.options[0].value === "false") {
        selection = [{
          value: "true"
        }];
      }
    }

    if (originalSelection !== selection) {
      (0, _callOnChange.default)(props, selection.map(function (item) {
        return item.value;
      }), "replace");
    }
  }, [props.allowDuplicates, props.multiple, props.creatable, props.options]);
  (0, _react.useEffect)(function () {
    (0, _callOnChange.default)(props, selection.map(function (item) {
      return item.value;
    }), "replace"); // Always update with different parsing
    // eslint-disable-next-line
  }, [props.parseTo]);
};

var _default = useUpdateSelection;
exports.default = _default;